==> jc-1.4.0.tar.gz: gnu/xml/xpath/ArithmeticExpr.h <==
// final class gnu.xml.xpath.ArithmeticExpr

// class file dependencies
// @dep_class ff406881d6f486a1 gnu_xml_xpath_ArithmeticExpr
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Expr

#include "gnu/xml/xpath/Expr.h"

#ifndef _JC_gnu_xml_xpath_ArithmeticExpr_H_
#define _JC_gnu_xml_xpath_ArithmeticExpr_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_ArithmeticExpr$sub_refs	_jc_gnu_xml_xpath_ArithmeticExpr$sub_refs;
typedef struct _jc_gnu_xml_xpath_ArithmeticExpr$sub_nonrefs	_jc_gnu_xml_xpath_ArithmeticExpr$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_ArithmeticExpr$refs	_jc_gnu_xml_xpath_ArithmeticExpr$refs;
typedef struct _jc_gnu_xml_xpath_ArithmeticExpr$nonrefs	_jc_gnu_xml_xpath_ArithmeticExpr$nonrefs;
typedef struct _jc_gnu_xml_xpath_ArithmeticExpr$object	_jc_gnu_xml_xpath_ArithmeticExpr$object;

typedef struct _jc_gnu_xml_xpath_ArithmeticExpr$fields_struct	_jc_gnu_xml_xpath_ArithmeticExpr$fields_struct;
typedef const struct _jc_gnu_xml_xpath_ArithmeticExpr$vmethods	_jc_gnu_xml_xpath_ArithmeticExpr$vmethods;
typedef const struct _jc_gnu_xml_xpath_ArithmeticExpr$vtable	_jc_gnu_xml_xpath_ArithmeticExpr$vtable;
typedef const struct _jc_gnu_xml_xpath_ArithmeticExpr$vtype	_jc_gnu_xml_xpath_ArithmeticExpr$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_ArithmeticExpr$fields_struct {
	jint	ADD;
	jint	DIVIDE;
	jint	MODULO;
	jint	MULTIPLY;
	jint	SUBTRACT;
};
extern _jc_gnu_xml_xpath_ArithmeticExpr$fields_struct _jc_gnu_xml_xpath_ArithmeticExpr$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_ArithmeticExpr$method$_init$4c192cc838c1ec30(_jc_env *, struct _jc_gnu_xml_xpath_ArithmeticExpr$object *, struct _jc_gnu_xml_xpath_Expr$object *, struct _jc_gnu_xml_xpath_Expr$object *, jint);

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_xpath_ArithmeticExpr$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_xpath_ArithmeticExpr$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_xpath_ArithmeticExpr$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_xpath_ArithmeticExpr$object *, struct _jc_object *, jint, jint);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_ArithmeticExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_xpath_ArithmeticExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_ArithmeticExpr$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_xpath_ArithmeticExpr$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_xpath_ArithmeticExpr$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_xpath_ArithmeticExpr$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_xpath_ArithmeticExpr$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_xpath_ArithmeticExpr$object *, struct _jc_object *, jint, jint);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_xpath_ArithmeticExpr$object *);
};

// Vtable
struct _jc_gnu_xml_xpath_ArithmeticExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_xpath_ArithmeticExpr$vmethods	gnu_xml_xpath_ArithmeticExpr;
};

// Vtype
struct _jc_gnu_xml_xpath_ArithmeticExpr$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_ArithmeticExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_ArithmeticExpr$sub_refs {
	struct _jc_gnu_xml_xpath_Expr$object	*lhs;
	struct _jc_gnu_xml_xpath_Expr$object	*rhs;
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_ArithmeticExpr$refs {
    _jc_gnu_xml_xpath_ArithmeticExpr$sub_refs	gnu_xml_xpath_ArithmeticExpr;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_ArithmeticExpr$sub_nonrefs {
	jint	op;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_ArithmeticExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_xpath_ArithmeticExpr$sub_nonrefs	gnu_xml_xpath_ArithmeticExpr;
};

// Object instance structure
struct _jc_gnu_xml_xpath_ArithmeticExpr$object {
	_jc_gnu_xml_xpath_ArithmeticExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_ArithmeticExpr$vtype	*vtype;
	_jc_gnu_xml_xpath_ArithmeticExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_ArithmeticExpr$vtype _jc_gnu_xml_xpath_ArithmeticExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_ArithmeticExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_ArithmeticExpr$class_object;

#endif	/* _JC_gnu_xml_xpath_ArithmeticExpr_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/ArithmeticExpr.h <==
// final class gnu.xml.xpath.ArithmeticExpr

// class file dependencies
// @dep_class ff406881d6f486a1 gnu_xml_xpath_ArithmeticExpr
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Expr

#include "gnu/xml/xpath/Expr.h"

#ifndef _JC_gnu_xml_xpath_ArithmeticExpr_H_
#define _JC_gnu_xml_xpath_ArithmeticExpr_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_ArithmeticExpr$sub_refs	_jc_gnu_xml_xpath_ArithmeticExpr$sub_refs;
typedef struct _jc_gnu_xml_xpath_ArithmeticExpr$sub_nonrefs	_jc_gnu_xml_xpath_ArithmeticExpr$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_ArithmeticExpr$refs	_jc_gnu_xml_xpath_ArithmeticExpr$refs;
typedef struct _jc_gnu_xml_xpath_ArithmeticExpr$nonrefs	_jc_gnu_xml_xpath_ArithmeticExpr$nonrefs;
typedef struct _jc_gnu_xml_xpath_ArithmeticExpr$object	_jc_gnu_xml_xpath_ArithmeticExpr$object;

typedef struct _jc_gnu_xml_xpath_ArithmeticExpr$fields_struct	_jc_gnu_xml_xpath_ArithmeticExpr$fields_struct;
typedef const struct _jc_gnu_xml_xpath_ArithmeticExpr$vmethods	_jc_gnu_xml_xpath_ArithmeticExpr$vmethods;
typedef const struct _jc_gnu_xml_xpath_ArithmeticExpr$vtable	_jc_gnu_xml_xpath_ArithmeticExpr$vtable;
typedef const struct _jc_gnu_xml_xpath_ArithmeticExpr$vtype	_jc_gnu_xml_xpath_ArithmeticExpr$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_ArithmeticExpr$fields_struct {
	jint	ADD;
	jint	DIVIDE;
	jint	MODULO;
	jint	MULTIPLY;
	jint	SUBTRACT;
};
extern _jc_gnu_xml_xpath_ArithmeticExpr$fields_struct _jc_gnu_xml_xpath_ArithmeticExpr$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_ArithmeticExpr$method$_init$4c192cc838c1ec30(_jc_env *, struct _jc_gnu_xml_xpath_ArithmeticExpr$object *, struct _jc_gnu_xml_xpath_Expr$object *, struct _jc_gnu_xml_xpath_Expr$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_xpath_ArithmeticExpr$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_xpath_ArithmeticExpr$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_xpath_ArithmeticExpr$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_xpath_ArithmeticExpr$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_ArithmeticExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_xpath_ArithmeticExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_ArithmeticExpr$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_xpath_ArithmeticExpr$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_xpath_ArithmeticExpr$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_xpath_ArithmeticExpr$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_xpath_ArithmeticExpr$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_xpath_ArithmeticExpr$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_xpath_ArithmeticExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_xpath_ArithmeticExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_xpath_ArithmeticExpr$vmethods	gnu_xml_xpath_ArithmeticExpr;
};

// Vtype
struct _jc_gnu_xml_xpath_ArithmeticExpr$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_ArithmeticExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_ArithmeticExpr$sub_refs {
	struct _jc_gnu_xml_xpath_Expr$object	*lhs;
	struct _jc_gnu_xml_xpath_Expr$object	*rhs;
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_ArithmeticExpr$refs {
    _jc_gnu_xml_xpath_ArithmeticExpr$sub_refs	gnu_xml_xpath_ArithmeticExpr;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_ArithmeticExpr$sub_nonrefs {
	jint	op;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_ArithmeticExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_xpath_ArithmeticExpr$sub_nonrefs	gnu_xml_xpath_ArithmeticExpr;
};

// Object instance structure
struct _jc_gnu_xml_xpath_ArithmeticExpr$object {
	_jc_gnu_xml_xpath_ArithmeticExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_ArithmeticExpr$vtype	*vtype;
	_jc_gnu_xml_xpath_ArithmeticExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_ArithmeticExpr$vtype _jc_gnu_xml_xpath_ArithmeticExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_ArithmeticExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_ArithmeticExpr$class_object;

#endif	/* _JC_gnu_xml_xpath_ArithmeticExpr_H_ */
